changeset 111123:cc83220d255d

Sync docs of cursor-in-non-selected-windows between Lisp and C. * lisp/frame.el (cursor-in-non-selected-windows): Sync doc with C version. * src/buffer.c (syms_of_buffer) <cursor-in-non-selected-windows>: Sync doc with Lisp version.
author Glenn Morris <rgm@gnu.org>
date Sat, 23 Oct 2010 14:13:39 -0700
parents 7f7432fcea56
children eed7831710a5
files lisp/ChangeLog lisp/frame.el src/ChangeLog src/buffer.c
diffstat 4 files changed, 19 insertions(+), 15 deletions(-) [+]
line wrap: on
line diff
--- a/lisp/ChangeLog	Sat Oct 23 14:02:44 2010 -0700
+++ b/lisp/ChangeLog	Sat Oct 23 14:13:39 2010 -0700
@@ -1,6 +1,7 @@
 2010-10-23  Glenn Morris  <rgm@gnu.org>
 
-	* frame.el (auto-hscroll-mode): Sync doc with C version.
+	* frame.el (auto-hscroll-mode, cursor-in-non-selected-windows):
+	Sync docs with C version.
 
 	* term/ns-win.el (xw-defined-colors):
 	* term/x-win.el (xw-defined-colors): Make docs identical to w32-win.
--- a/lisp/frame.el	Sat Oct 23 14:02:44 2010 -0700
+++ b/lisp/frame.el	Sat Oct 23 14:13:39 2010 -0700
@@ -1593,12 +1593,12 @@
 
 
 (defcustom cursor-in-non-selected-windows t
-  "Non-nil means show a hollow box cursor in non-selected windows.
-If nil, don't show a cursor except in the selected window.
-If t, display a cursor related to the usual cursor type
- \(a solid box becomes hollow, a bar becomes a narrower bar).
+  "Non-nil means show a cursor in non-selected windows.
+If nil, only shows a cursor in the selected window.
+If t, displays a cursor related to the usual cursor type
+\(a solid box becomes hollow, a bar becomes a narrower bar).
 You can also specify the cursor type as in the `cursor-type' variable.
-Use Custom to set this variable to get the display updated."
+Use Custom to set this variable and update the display."
   :tag "Cursor In Non-selected Windows"
   :type 'boolean
   :group 'cursor
--- a/src/ChangeLog	Sat Oct 23 14:02:44 2010 -0700
+++ b/src/ChangeLog	Sat Oct 23 14:13:39 2010 -0700
@@ -1,6 +1,7 @@
 2010-10-23  Glenn Morris  <rgm@gnu.org>
 
-	* xdisp.c (syms_of_xdisp) <auto-hscroll-mode>: Sync doc with Lisp.
+	* buffer.c (syms_of_buffer) <cursor-in-non-selected-windows>:
+	* xdisp.c (syms_of_xdisp) <auto-hscroll-mode>: Sync docs with Lisp.
 
 2010-10-23  Eli Zaretskii  <eliz@gnu.org>
 
--- a/src/buffer.c	Sat Oct 23 14:02:44 2010 -0700
+++ b/src/buffer.c	Sat Oct 23 14:13:39 2010 -0700
@@ -1,8 +1,8 @@
 /* Buffer manipulation primitives for GNU Emacs.
-   Copyright (C) 1985, 1986, 1987, 1988, 1989, 1993, 1994,
-                 1995, 1997, 1998, 1999, 2000, 2001, 2002,
-                 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010
-                 Free Software Foundation, Inc.
+
+Copyright (C) 1985, 1986, 1987, 1988, 1989, 1993, 1994, 1995, 1997,
+  1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008,
+  2009, 2010  Free Software Foundation, Inc.
 
 This file is part of GNU Emacs.
 
@@ -6140,8 +6140,12 @@
 
   DEFVAR_PER_BUFFER ("cursor-in-non-selected-windows",
 		     &current_buffer->cursor_in_non_selected_windows, Qnil,
-		     doc: /* *Cursor type to display in non-selected windows.
-The value t means to use hollow box cursor.  See `cursor-type' for other values.  */);
+		     doc: /* *Non-nil means show a cursor in non-selected windows.
+If nil, only shows a cursor in the selected window.
+If t, displays a cursor related to the usual cursor type
+\(a solid box becomes hollow, a bar becomes a narrower bar).
+You can also specify the cursor type as in the `cursor-type' variable.
+Use Custom to set this variable and update the display."  */);
 
   DEFVAR_LISP ("kill-buffer-query-functions", &Vkill_buffer_query_functions,
 	       doc: /* List of functions called with no args to query before killing a buffer.
@@ -6218,5 +6222,3 @@
   Fput (intern_c_string ("erase-buffer"), Qdisabled, Qt);
 }
 
-/* arch-tag: e48569bf-69a9-4b65-a23b-8e68769436e1
-   (do not change this comment) */